<?php

namespace Myriad\Queue\Drivers\Google\Commands;

use Illuminate\Console\Command;
use Illuminate\Queue\QueueManager;
use Myriad\Queue\Drivers\Google\PubSubQueue;

class ConsumeQueueCommand extends Command
{

    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'google-queue:consume {connection} {queue}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Consume all of the jobs currently on the specified queue.';

    /**
     * Execute the console command.
     * @param  QueueManager  $queueManager
     */
    public function handle(QueueManager $queueManager)
    {
        $connection = $queueManager->connection($this->argument('connection'));

        if (!($connection instanceof PubSubQueue)) {
            $this->error('Specified connection does not implement the Google Pub/Sub driver');
            return;
        }

        $count = $connection->consume($this->argument('queue'));

        $this->info('Consumed '.$count.' messages');
    }

}
